@@ -6,6 +6,6 @@ void Store::setSource(std::string const &fname)
 
 //    cout << "Sourcefile: " << d_sourceFile << '\n';
 
-    d_currentIdx = d_xrefData.size();
+    d_currentIdx = d_xrefVector.size();
     define("GLOBALS " + fname + " " + d_objFile, false);
 }
